@@ -133,7 +133,7 @@ class PlaywrightBrowserStub(PlaywrightBrowserImpl, Browser):
         """获得一个浏览器页面
 
         Args:
-            context: bool, 是否使用 Browser Context，详见 <https://playwright.dev/python/docs/browser-contexts#browser-context>
+            context (bool): 是否使用 Browser Context，详见 <https://playwright.dev/python/docs/browser-contexts#browser-context>
 
         Usage:
             ```python
@@ -165,7 +165,7 @@ class PlaywrightContextImpl(ExportInterface["PlaywrightService"]):
     if not TYPE_CHECKING:
 
         def __getattr__(self, name: str) -> Any:
-            return self.browser.__getattribute__(name)
+            return self.context.__getattribute__(name)
 
 
 class PlaywrightContextStub(PlaywrightContextImpl, BrowserContext):
